@@ -50,6 +50,7 @@ class ClientModel(ABC):
                     self.__delitem__(key)
                 except KeyError:
                     pass
+        self.base_values_list = ["total","units","author","plugin_version","heartbeat_required","date_created","querytime"]
         self.validate()
 
     def __getitem__(self, key):
@@ -107,20 +108,9 @@ class ClientModel(ABC):
         ''' calculate the total of all metrics without base values '''
         total = 0
         for key, value in self.dict.items():
-            if key == 'total':
-                continue
-            elif key == 'units':
-                continue
-            elif key == 'author':
-                continue
-            elif key == 'plugin_version':
-                continue
-            elif key == 'heartbeat_required':
-                continue
-            elif key == 'date_created':
-                continue
-            elif key.lower().startswith("querytime"):
-                continue
+            for i in self.base_values_list:
+                if key == i:
+                    continue
             else:
                 try:
                     total += int(value)
